@@ -166,7 +166,7 @@ class Reviewer(object):
         self._async_get(self.page_url, callback)
 
     def content_loaded(self, url, response):
-        if response.status_code > 399:
+        if response.status_code > 399 or response.text is None:
             if response.text:
                 text = response.text.decode('rotunicode')
             else:
